@@ -29,6 +29,13 @@
 
 #include "rvlog.h"
 
+#define WFASSERT(msg)  do {					       	      \
+    fprintf(stderr,						              \
+	    _("%s:%i: Warning: assertion failed in function `%s': %s\n"),     \
+  	  __FILE__, __LINE__, __func__, msg);			              \
+    cerr << _("This should not have happened, please signal it to the author.") << '\n'; \
+  } while(0);
+
 extern rvlog wflogs_log; // RV@@9
 /*
 //#define wf_log(level, format, args...) \
