@@ -23,6 +23,9 @@
 #define _WFTIMEDIFF_H
 
 #include <string>
+#if defined(__FreeBSD__)
+#include <sys/types.h>
+#endif
 
 string timediff_tostr(time_t start, time_t end);
 string timediff_tohumanstr(time_t start, time_t end);
