@@ -28,6 +28,9 @@ using namespace std;
 #include <string>
 
 #include <stdio.h>
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
+#include <unistd.h> /* for select() */
+#endif
 #include <sys/stat.h>
 #include <signal.h>
 #include <errno.h>
@@ -42,15 +45,14 @@ using namespace std;
 #include "realtime.h"
 #include "defs.h"
 
-// PASSIVE_WAIT is a macro which marks code to add for passive wait (logging
-// through a device, for example) RV@@8
-
 #define DEFAULT_SORT_CRITERIAS  "-count,time,dipaddr,protocol,dport"
 #define DEFAULT_PARSE_STRICTNESS  WF_LOGENTRIES_PARSING_STRICTNESS_WARNING
 #define DEFAULT_PARSE_STRICTNESS_S  "warning"
 
 #define WFLOGS_PROMPT "wflogs> "
 
+extern void wf_inmodule_netfilter_realtime_read(); // remove this RV@@9
+
 char* configfilename = ""; /* define it with a #define RV@@7 */
 bool realtime = false, interactive = false;
 int verbose = 0;
@@ -527,7 +529,7 @@ main(int argc, char* argv[]) {
     /* Output logs on stdout. */
     if (output_module->print(*logentries, cout) == false) {
       wflogs_log.log(RVLOG_ERROR, _("Error: output failed."));
-      exit(1);  // really exit here all the way? ALL@8
+      exit(1);  // really exit here all the way? ALL@@8
     }
   }
 
@@ -589,40 +591,45 @@ main(int argc, char* argv[]) {
     while (1) {
       fd_set fdset;
 
-      /* Handle active wait from log file */
-      char line[WF_LOGLINE_MAXLEN];
-      bool displayed = false;
       /* We read the line in any case (even if we're not in realtime mode
 	 at this time), to keep track of the right line number in case we would
 	 set realtime mode later (even if currently turned off). */
-      u_int16_t line_block = 0;
+      char line[WF_LOGLINE_MAXLEN];
+      /* displayed: true if something was displayed in loop, so that we can
+	 eventually refresh display (especially if using readline) */
+      bool displayed = false;
+      uint16_t line_block = 10; /* read by blocks of x lines */
+      /* Handle active wait from log file */
       while (fgets(line, sizeof(line), file)) {
 	lineno++; /* there is a new line */
 	if (realtime) {
 	  if (wf_realtime_parse(line, filename, lineno, input_modules,
-			    strict_parsing, myfilter, output_module))
-	    displayed = true;
+				strict_parsing, myfilter, output_module)) {
+	    if (interactive)
+	      displayed = true;
+	  }
 
 	  /* If realtime and interactive mode are both enabled, read only
 	     a few lines to still allow a little interactivity even when on
 	     log flood. */
-	  if (interactive && line_block++ > 10)
+	  if (interactive && --line_block != 0)
 	      break;
 	}
       }
       /* no more new line */
       
-      if (displayed && interactive)
+      if (interactive && displayed)
 	interact->display_update();
 
       FD_ZERO(&fdset);
       if (interactive)
 	FD_SET(0, &fdset);
       int fds = 0; // only stdin for the moment RV@@9
-#ifdef PASSIVE_WAIT
-      if (realtime)
-	FD_SET(wflogs_realtime_sockd, &fdset);
-#endif
+      /* Add fd for passive wait from log stream */
+      if (realtime) {
+	FD_SET(wflogs_realtime_fd, &fdset);
+	fds = wflogs_realtime_fd;
+      }
 
       struct timeval tv = { 1, 0 }; /* 1 second timeout */
     intr:
@@ -640,13 +647,13 @@ main(int argc, char* argv[]) {
       if (interactive && FD_ISSET(0, &fdset))
 	interact->callback(); /* every char if readline, every line otherw. */
 
-#ifdef PASSIVE_WAIT
       /* Handle passive wait from log stream */
-      if (realtime && FD_ISSET(wflogs_realtime_sockd, &fdset)) {
+      if (realtime && FD_ISSET(wflogs_realtime_fd, &fdset)) {
+	cout << "LOGGGG" << endl; // RV@@9
+	wf_inmodule_netfilter_realtime_read();
 	if (interactive)
 	  interact->display_update();
       }
-#endif
     }
   }
 
